@@ -7,8 +7,6 @@ import (
 	"fmt"
 	"time"
 
-	"monis.app/go/openshift/controller"
-
 	v1 "k8s.io/api/core/v1"
 	kapierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -16,10 +14,11 @@ import (
 	informers "k8s.io/client-go/informers/core/v1"
 	kcoreclient "k8s.io/client-go/kubernetes/typed/core/v1"
 	listers "k8s.io/client-go/listers/core/v1"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 
 	ocontroller "github.com/openshift/library-go/pkg/controller"
 	"github.com/openshift/library-go/pkg/crypto"
+	"github.com/openshift/operator-boilerplate-legacy/pkg/controller"
 	"github.com/openshift/service-ca-operator/pkg/controller/api"
 )
 
